/************************************************************************
 *   IRC - Internet Relay Chat, modules/server/server.c
 *   This file is copyright (C) 2001 Andrew Suffield
 *                                    <asuffield@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#include "config.h"
#include "msg.h"
#include "modules.h"
#include "parse.h"
#include "server.h"
#include "hooks.h"
#include "ircd.h"
#include "send.h"
#include "s_log.h"
#include "client.h"
#include "s_bsd.h"

#include <string.h>

MODULE("server")

static struct module_handle *mh;
static char desc[] = "Remote server support";
static char server_version[] = RELEASE;

mod_deinit_func server_deinit;

#ifdef STATIC_MODULES
struct module_handle *
server_init(void)
#else
struct module_handle *
_modinit(void)
#endif
{
  if (check_temp_invites != NULL)
    return NULL;

  if (!(mh = register_module(_name, desc, server_version, &server_deinit)))
    return NULL;

  mod_add_cmd(&burstdone_msgtab, mh);
  mod_add_cmd(&capab_msgtab, mh);
  mod_add_cmd(&cclear_msgtab, mh);
  mod_add_cmd(&chall_msgtab, mh);
  mod_add_cmd(&channelts_msgtab, mh);
  mod_add_cmd(&clabort_msgtab, mh);
  mod_add_cmd(&clack_msgtab, mh);
  mod_add_cmd(&clock_msgtab, mh);
  mod_add_cmd(&error_msgtab, mh);
  mod_add_cmd(&pass_msgtab, mh);
  mod_add_cmd(&ping_msgtab, mh);
  mod_add_cmd(&pong_msgtab, mh);
  mod_add_cmd(&quit_msgtab, mh);
  mod_add_cmd(&resp_msgtab, mh);
  mod_add_cmd(&server_msgtab, mh);
  mod_add_cmd(&spingtime_msgtab, mh);
  mod_add_cmd(&squit_msgtab, mh);
  mod_add_cmd(&sjoin_msgtab, mh);
  mod_add_cmd(&stopic_msgtab, mh);
  mod_add_cmd(&svinfo_msgtab, mh);
  return mh;
}

void
server_deinit(int type)
{
  if (type == UNLOAD_USER)
    {
      /* Drop every remote server connection */
#if 0
      int i;
      struct Client *acptr;
      for (i = 0; i <= highest_fd; i++)
	{
	  if (!(acptr = local[i]))
	    continue;
	  if (IsClient(acptr))
	    {
	      sendto_one(acptr,
			 ":%s NOTICE %s :Server Terminating, core unloaded.",
			 me.name, acptr->name);
	    }
	  else if (IsServer(acptr))
	    sendto_one(acptr, ":%s ERROR :Terminated, core unloaded.",
		       me.name);
	}
#endif
    }
}
